@@ -1,4 +1,6 @@
 from . import main
 from .main import Pygame
 from .element import Element
-from .image import Image
\ No newline at end of file
+from .image import Image
+from .sound import Sound
+from .music import Music
\ No newline at end of file
