@@ -1,10 +1,7 @@
 import os
 import pygame
 
-from .main import Pygame
-from .image import Image
-from .sound import Sound
-from .music import Music
+from .main import Pygame, Image, Sound, Music
 
 class Element:
     def __init__(self, image : Image, parent : Pygame, centerPosition = [0, 0], speed = [1, 1]):
